@@ -3,9 +3,9 @@ package com.sun.tools.javap.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "12.0.2+10" },
-            { "jdk", "12.0.2" },
-            { "release", "12.0.2" },
+            { "full", "17.0.2+8-86" },
+            { "jdk", "17.0.2" },
+            { "release", "17.0.2" },
         };
     }
 }
