@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -725,7 +721,6 @@ public class LocaleNames_az_Cyrl extends OpenListResourceBundle {
             { "zxx", "\u0434\u0438\u043b \u043c\u04d9\u0437\u043c\u0443\u043d\u0443 \u0458\u043e\u0445\u0434\u0443\u0440" },
             { "zza", "\u0437\u0430\u0437\u0430" },
             { "Cyrl", "\u041a\u0438\u0440\u0438\u043b" },
-            { "root", "\u0440\u0443\u0442" },
             { "de_AT", "\u0410\u0432\u0441\u0442\u0440\u0438\u0458\u0430 \u0430\u043b\u043c\u0430\u043d\u04b9\u0430\u0441\u044b" },
             { "de_CH", "\u0418\u0441\u0432\u0435\u0447\u0440\u04d9 \u0458\u04af\u043a\u0441\u04d9\u043a \u0430\u043b\u043c\u0430\u043d\u04b9\u0430\u0441\u044b" },
             { "en_AU", "\u0410\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u0458\u0430 \u0438\u043d\u049d\u0438\u043b\u0438\u0441\u04b9\u04d9\u0441\u0438" },
